@@ -100,6 +100,19 @@ namespace Breeze
         //* frame outline color, using animations
         QColor frameOutlineColor( const QPalette&, bool mouseOver = false, bool hasFocus = false, qreal opacity = AnimationData::OpacityInvalid, AnimationMode = AnimationNone ) const;
 
+        //* focus outline color, using animations
+        QColor focusOutlineColor( const QPalette& ) const;
+
+        //* hover outline color, using animations
+        QColor hoverOutlineColor( const QPalette& ) const;
+
+        //* focus outline color, using animations
+        QColor buttonFocusOutlineColor( const QPalette& ) const;
+
+        //* hover outline color, using animations
+        QColor buttonHoverOutlineColor( const QPalette& ) const;
+
+
         //* side panel outline color, using animations
         QColor sidePanelOutlineColor( const QPalette&, bool hasFocus = false, qreal opacity = AnimationData::OpacityInvalid, AnimationMode = AnimationNone ) const;
 
@@ -122,6 +135,13 @@ namespace Breeze
         //* return altered palette suitable for tinted frames
         QPalette sideViewPalette( const QPalette& ) const;
 
+        //* arrow outline color
+        QColor arrowColor( const QPalette&, QPalette::ColorGroup, QPalette::ColorRole ) const;
+
+        //* arrow outline color
+        QColor arrowColor( const QPalette& palette, QPalette::ColorRole role ) const
+        { return arrowColor( palette, palette.currentColorGroup(), role ); }
+
         //* arrow outline color, using animations
         QColor arrowColor( const QPalette&, bool mouseOver, bool hasFocus, qreal opacity = AnimationData::OpacityInvalid, AnimationMode = AnimationNone ) const;
 
@@ -129,7 +149,7 @@ namespace Breeze
         QColor buttonOutlineColor( const QPalette&, bool mouseOver, bool hasFocus, qreal opacity = AnimationData::OpacityInvalid, AnimationMode = AnimationNone ) const;
 
         //* button panel color, using animations
-        QColor buttonBackgroundColor( const QPalette&, bool mouseOver, bool hasFocus, qreal opacity = AnimationData::OpacityInvalid, AnimationMode = AnimationNone ) const;
+        QColor buttonBackgroundColor( const QPalette&, bool mouseOver, bool hasFocus, bool sunken, qreal opacity = AnimationData::OpacityInvalid, AnimationMode = AnimationNone ) const;
 
         //* tool button color
         QColor toolButtonColor( const QPalette&, bool mouseOver, bool hasFocus, bool sunken, qreal opacity = AnimationData::OpacityInvalid, AnimationMode = AnimationNone ) const;
@@ -158,7 +178,7 @@ namespace Breeze
         void renderDebugFrame( QPainter*, const QRect& ) const;
 
         //* focus rect
-        void renderFocusRect( QPainter*, const QRect&, const QColor& ) const;
+        void renderFocusRect( QPainter*, const QRect&, const QColor&, const QColor& outline = QColor(), Sides = 0 ) const;
 
         //* focus line
         void renderFocusLine( QPainter*, const QRect&, const QColor& ) const;
@@ -182,7 +202,7 @@ namespace Breeze
         void renderToolBoxFrame( QPainter*, const QRect&, int tabWidth, const QColor& color ) const;
 
         //* tab widget frame
-        void renderTabWidgetFrame( QPainter*, const QRect&, const QColor& color, const QColor& outline, Corners corners ) const;
+        void renderTabWidgetFrame( QPainter*, const QRect&, const QColor& color, const QColor& outline, Corners ) const;
 
         //* selection frame
         void renderSelection( QPainter*, const QRect&, const QColor& ) const;
@@ -190,9 +210,15 @@ namespace Breeze
         //* separator
         void renderSeparator( QPainter*, const QRect&, const QColor&, bool vertical = false ) const;
 
+        //* checkbox
+        void renderCheckBoxBackground( QPainter*, const QRect&, const QColor& color, bool sunken ) const;
+
         //* checkbox
         void renderCheckBox( QPainter*, const QRect&, const QColor& color, const QColor& shadow, bool sunken, CheckBoxState state, qreal animation = AnimationData::OpacityInvalid ) const;
 
+        //* radio button
+        void renderRadioButtonBackground( QPainter*, const QRect&, const QColor& color, bool sunken ) const;
+
         //* radio button
         void renderRadioButton( QPainter*, const QRect&, const QColor& color, const QColor& shadow, bool sunken, RadioButtonState state, qreal animation = AnimationData::OpacityInvalid ) const;
 
@@ -200,7 +226,7 @@ namespace Breeze
         void renderSliderGroove( QPainter*, const QRect&, const QColor& ) const;
 
         //* slider handle
-        void renderSliderHandle( QPainter*, const QRect&, const QColor&, const QColor& outline, const QColor& shadow, bool focus, bool sunken ) const;
+        void renderSliderHandle( QPainter*, const QRect&, const QColor&, const QColor& outline, const QColor& shadow, bool sunken ) const;
 
         //* dial groove
         void renderDialGroove( QPainter*, const QRect&, const QColor& ) const;
@@ -294,8 +320,8 @@ namespace Breeze
         void init( void );
 
         //* frame radius
-        qreal frameRadius( void ) const
-        { return qreal( Metrics::Frame_FrameRadius )-0.5; }
+        qreal frameRadius( qreal bias = 0 ) const
+        { return qMax( qreal( Metrics::Frame_FrameRadius ) - 0.5 + bias, 0.0 ); }
 
         //* return rectangle for widgets shadow, offset depending on light source
         QRectF shadowRect( const QRectF& ) const;
