@@ -56,11 +56,19 @@ namespace Breeze
         //* unregister widget
         void unregisterWidget( QObject* );
 
+        protected Q_SLOTS:
+
         //* adjust palettes
-        void adjustPalettes( const QPalette& );
+        void adjustPendingPalettes( void );
 
         protected:
 
+        //* adjust widget palette
+        bool acceptWidget( QWidget* ) const;
+
+        //* adjust palettes
+        void adjustPalettes( const QPalette& );
+
         //* adjust widget palette
         bool adjustPalette( QWidget*, const QPalette& ) const;
 
@@ -73,6 +81,9 @@ namespace Breeze
         /** it is used to keep track of application palette changes */
         QWidget* _widget = nullptr;
 
+        //* widget set
+        QSet<QObject*> _pendingWidgets;
+
         //* widget set
         QSet<QObject*> _registeredWidgets;
 
